AppVersionStatus class

Info about the most recent and current versions of the software that are accessible through the Apple App Store or Google Play Store.

Properties

appVersion → String
final
hashCode → int
The hash code for this object.
no setterinherited
isUpdateAvailable → bool
Returns true if the store version of the application is greater than the local version.
no setter
releaseNotes → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
storeVersion → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited